@@ -79,13 +79,17 @@ def get_html(filename, inline_css):
         date=datetime.datetime.now().strftime("%Y/%m/%d"),
         time=datetime.datetime.now().strftime("%H:%M:%S"),
         scaling_factor=gv.scaling_factor,
+        ctme=gv.ctme,
+        nps=gv.nps,
         parameters=gv.parameters,
+        fatal_errors=gv.fatal_errors,
         k_eff=gv.k_effective,
         tally_list=gv.tally_list,
         tally_types=gv.f_types,
         f2_tallies=gv.F2_tallies,
         f4_tallies=gv.F4_tallies,
         f5_tallies=gv.F5_tallies,
+        f6_tallies=gv.F6_tallies,
         warnings=gv.warnings,
         comments=gv.comments,
         duplicate_surfaces=gv.duplicate_surfaces,
